methods_overwrite_impl <- function() {
  vctrs::s3_register("dplyr::add_count", "data.frame", add_count.duckplyr_df)
  vctrs::s3_register("dplyr::anti_join", "data.frame", anti_join.duckplyr_df)
  vctrs::s3_register("dplyr::arrange", "data.frame", arrange.duckplyr_df)
  vctrs::s3_register("dplyr::auto_copy", "data.frame", auto_copy.duckplyr_df)
  vctrs::s3_register("dplyr::collect", "data.frame", collect.duckplyr_df)
  vctrs::s3_register("dplyr::compute", "data.frame", compute.duckplyr_df)
  vctrs::s3_register("dplyr::count", "data.frame", count.duckplyr_df)
  vctrs::s3_register("dplyr::cross_join", "data.frame", cross_join.duckplyr_df)
  vctrs::s3_register("dplyr::distinct", "data.frame", distinct.duckplyr_df)
  vctrs::s3_register("dplyr::do", "data.frame", do.duckplyr_df)
  vctrs::s3_register("dplyr::filter", "data.frame", filter.duckplyr_df)
  vctrs::s3_register("dplyr::full_join", "data.frame", full_join.duckplyr_df)
  vctrs::s3_register("dplyr::group_by", "data.frame", group_by.duckplyr_df)
  vctrs::s3_register("dplyr::group_indices", "data.frame", group_indices.duckplyr_df)
  vctrs::s3_register("dplyr::group_keys", "data.frame", group_keys.duckplyr_df)
  vctrs::s3_register("dplyr::group_map", "data.frame", group_map.duckplyr_df)
  vctrs::s3_register("dplyr::group_modify", "data.frame", group_modify.duckplyr_df)
  vctrs::s3_register("dplyr::group_nest", "data.frame", group_nest.duckplyr_df)
  vctrs::s3_register("dplyr::group_size", "data.frame", group_size.duckplyr_df)
  vctrs::s3_register("dplyr::group_split", "data.frame", group_split.duckplyr_df)
  vctrs::s3_register("dplyr::group_trim", "data.frame", group_trim.duckplyr_df)
  vctrs::s3_register("dplyr::group_vars", "data.frame", group_vars.duckplyr_df)
  vctrs::s3_register("dplyr::groups", "data.frame", groups.duckplyr_df)
  vctrs::s3_register("dplyr::inner_join", "data.frame", inner_join.duckplyr_df)
  vctrs::s3_register("dplyr::intersect", "data.frame", intersect.duckplyr_df)
  vctrs::s3_register("dplyr::left_join", "data.frame", left_join.duckplyr_df)
  vctrs::s3_register("dplyr::mutate", "data.frame", mutate.duckplyr_df)
  vctrs::s3_register("dplyr::n_groups", "data.frame", n_groups.duckplyr_df)
  vctrs::s3_register("dplyr::nest_by", "data.frame", nest_by.duckplyr_df)
  vctrs::s3_register("dplyr::nest_join", "data.frame", nest_join.duckplyr_df)
  vctrs::s3_register("dplyr::pull", "data.frame", pull.duckplyr_df)
  vctrs::s3_register("dplyr::reframe", "data.frame", reframe.duckplyr_df)
  vctrs::s3_register("dplyr::relocate", "data.frame", relocate.duckplyr_df)
  vctrs::s3_register("dplyr::rename", "data.frame", rename.duckplyr_df)
  vctrs::s3_register("dplyr::rename_with", "data.frame", rename_with.duckplyr_df)
  vctrs::s3_register("dplyr::right_join", "data.frame", right_join.duckplyr_df)
  vctrs::s3_register("dplyr::rows_append", "data.frame", rows_append.duckplyr_df)
  vctrs::s3_register("dplyr::rows_delete", "data.frame", rows_delete.duckplyr_df)
  vctrs::s3_register("dplyr::rows_insert", "data.frame", rows_insert.duckplyr_df)
  vctrs::s3_register("dplyr::rows_patch", "data.frame", rows_patch.duckplyr_df)
  vctrs::s3_register("dplyr::rows_update", "data.frame", rows_update.duckplyr_df)
  vctrs::s3_register("dplyr::rows_upsert", "data.frame", rows_upsert.duckplyr_df)
  vctrs::s3_register("dplyr::rowwise", "data.frame", rowwise.duckplyr_df)
  vctrs::s3_register("dplyr::select", "data.frame", select.duckplyr_df)
  vctrs::s3_register("dplyr::semi_join", "data.frame", semi_join.duckplyr_df)
  vctrs::s3_register("dplyr::setdiff", "data.frame", setdiff.duckplyr_df)
  vctrs::s3_register("dplyr::setequal", "data.frame", setequal.duckplyr_df)
  vctrs::s3_register("dplyr::slice", "data.frame", slice.duckplyr_df)
  vctrs::s3_register("dplyr::slice_head", "data.frame", slice_head.duckplyr_df)
  vctrs::s3_register("dplyr::slice_sample", "data.frame", slice_sample.duckplyr_df)
  vctrs::s3_register("dplyr::slice_tail", "data.frame", slice_tail.duckplyr_df)
  vctrs::s3_register("dplyr::summarise", "data.frame", summarise.duckplyr_df)
  vctrs::s3_register("dplyr::symdiff", "data.frame", symdiff.duckplyr_df)
  vctrs::s3_register("dplyr::transmute", "data.frame", transmute.duckplyr_df)
  vctrs::s3_register("dplyr::ungroup", "data.frame", ungroup.duckplyr_df)
  vctrs::s3_register("dplyr::union", "data.frame", union.duckplyr_df)
  vctrs::s3_register("dplyr::union_all", "data.frame", union_all.duckplyr_df)
}
